@@ -504,6 +504,22 @@ ctrCache <- function(xname, xvalue = NULL, verbose = FALSE) {
 #'
 ctrDb <- function(con) {
 
+  ## ensure requirements
+  if (!requireNamespace("nodbi", quietly = TRUE)) {
+    stop("Install package 'nodbi' to use this function.",
+         call. = FALSE)
+  }
+  minV <- sub(
+    ".*nodbi[(<>=[:space:]]+([.0-9]+?)\\).*", "\\1",
+    utils::packageDescription("ctrdata", fields = "Imports")
+  )
+  if (!(utils::packageVersion("nodbi") >=
+        package_version(minV))) {
+    stop("Update package 'nodbi' to version ",
+         minV, " or later to use this function.",
+         call. = FALSE)
+  }
+
   ## postgres
   if (inherits(con, "src_postgres")) {
 
@@ -864,7 +880,6 @@ ctrMultiDownload <- function(
       destfiles = list(downloadValue$destfile[toDo]),
       resume = canR,
       progress = progress,
-      timeout = Inf,
       multiplex = multiplex,
       c(getOption("httr_config")[["options"]],
         accept_encoding = "gzip,deflate,zstd,br")
@@ -1053,20 +1068,13 @@ ctrDocsDownload <- function(
   documents.path <- normalizePath(documents.path, mustWork = TRUE)
   if (createdDir) message("- Created directory ", documents.path)
 
-  # documents download
-  message("- Creating subfolder for each trial")
-
   # add destination file directory path
   dlFiles$filepath <- file.path(documents.path, dlFiles$`_id`)
 
-  # create subdirectories by trial
-  invisible(sapply(
-    unique(dlFiles$filepath), function(i) if (!dir.exists(i))
-      dir.create(i, showWarnings = FALSE, recursive = TRUE)
-  ))
+  # create full filepathname
+  dlFiles$filepathname <- file.path(dlFiles$filepath, dlFiles$filename)
 
   # check if destination document exists
-  dlFiles$filepathname <- file.path(dlFiles$filepath, dlFiles$filename)
   dlFiles$fileexists <- file.exists(dlFiles$filepathname) &
     file.size(dlFiles$filepathname) > 20L
 
@@ -1075,6 +1083,12 @@ ctrDocsDownload <- function(
 
     message("- Creating empty document placeholders (max. ", nrow(dlFiles), ")")
 
+    # create subdirectories by trial
+    invisible(sapply(
+      unique(dlFiles$filepath), function(i) if (!dir.exists(i))
+        dir.create(i, showWarnings = FALSE, recursive = TRUE)
+    ))
+
     # create empty files
     tmp <-
       sapply(
@@ -1096,10 +1110,33 @@ ctrDocsDownload <- function(
       grepl(documents.regexp, dlFiles$filename, ignore.case = TRUE), ,
       drop = FALSE]
 
+    # documents download
+    message("- Creating subfolder for each trial")
+
+    # create subdirectories by trial
+    invisible(sapply(
+      unique(dlFiles$filepath), function(i) if (!dir.exists(i))
+        dir.create(i, showWarnings = FALSE, recursive = TRUE)
+    ))
+
     # inform
     message("- Downloading ",
             nrow(dlFiles[!dlFiles$fileexists, , drop = FALSE]),
-            " missing documents")
+            " missing documents " , appendLF = FALSE)
+
+    # check and remove duplicate filepathname rows
+    duplicateFiles <- duplicated(tolower(dlFiles$filepathname))
+    if (any(duplicateFiles)) {
+      message(
+        "(excluding ", sum(duplicateFiles), " ",
+        "files with duplicate names for saving, e.g. ",
+        paste0(
+          sample(dlFiles$filepathname[duplicateFiles], 3),
+          collapse = ", "),
+        ") ", appendLF = FALSE)
+      dlFiles <- dlFiles[!duplicateFiles, , drop = FALSE]
+    }
+    message()
 
     # do download
     tmp <- ctrMultiDownload(
@@ -1228,12 +1265,6 @@ dbCTRLoadJSONFiles <- function(dir, con, verbose) {
 
       ## get _id's
 
-      # main function for fast reading,
-      # switching off warning about final EOL missing
-      fd <- file(description = tempFiles[tempFile],
-                 open = "rt", blocking = TRUE)
-      on.exit(try(close(fd), silent = TRUE), add = TRUE)
-
       # inform user
       message(
         "JSON file #: ", tempFile, " / ", fc,
@@ -1293,15 +1324,12 @@ dbCTRLoadJSONFiles <- function(dir, con, verbose) {
 
         # step into line by line mode
         fdLines <- file(tempFiles[tempFile], open = "rt", blocking = TRUE)
-        fLineOut <- tempfile(pattern = "tmpOneLine", tmpdir = dir, fileext = ".ndjson")
-        on.exit(unlink(fLineOut), add = TRUE)
         while (TRUE) {
           tmpOneLine <- readLines(con = fdLines, n = 1L, warn = FALSE)
           if (length(tmpOneLine) == 0L || !nchar(tmpOneLine)) break
           id <- sub(".*\"_id\":[ ]*\"(.*?)\".*", "\\1", tmpOneLine)
-          cat(tmpOneLine, file = fLineOut)
           tmp <- suppressWarnings(suppressMessages(nodbi::docdb_create(
-            src = con, key = con$collection, value = fLineOut)))
+            src = con, key = con$collection, value = paste0("[", tmpOneLine, "]"))))
           nImported <- nImported + tmp
           if (tmp) idSuccess <- c(idSuccess, id)
           if (!tmp) idFailed <- c(idFailed, id)
@@ -1317,9 +1345,6 @@ dbCTRLoadJSONFiles <- function(dir, con, verbose) {
         idAnnotation <- c(idAnnotation, annoDf[, "annotation", drop = TRUE])
       }
 
-      # close this file
-      close(fd)
-
       # return values
       list(success = idSuccess,
            failed = idFailed,
