@@ -298,6 +298,12 @@ expect_true(
   ctrOpenSearchPagesInBrowser(
     copyright = TRUE))
 
+# test
+expect_equal(
+  ctrOpenSearchPagesInBrowser(
+    url = "https://clinicaltrials.gov/expert-search?term=heart attack AND AREA[LocationCountry]United States AND AREA[LocationStatus]Recruiting"
+  ), "https://clinicaltrials.gov/expert-search?term=heart attack AND AREA[LocationCountry]United States AND AREA[LocationStatus]Recruiting")
+
 # test
 expect_equal(
   ctrOpenSearchPagesInBrowser(
@@ -450,7 +456,6 @@ dF <- data.frame(
 dL <- suppressMessages(
   dfTrials2Long(dF)
 )
-
 dL2 <- dfTrials2Long(
   df = dF[, 4:1]
 )
@@ -497,3 +502,4 @@ expect_true(
 
 # cleanup
 rm(dF, dL)
+
