@@ -10,6 +10,15 @@ if (!checkInternet()) exit_file("Reason: no internet connectivity")
 #### CTGOV ####
 tf <- function() {
 
+  # test
+  expect_error(
+    dbQueryHistory(
+      nodbi::src_sqlite(
+        dbname = ":memory:")
+    ),
+    "Specify parameter"
+  )
+
   # create database object
   dbc <- suppressWarnings(nodbi::src_sqlite(
     dbname = ":memory:",
@@ -30,10 +39,10 @@ tf <- function() {
   if (httr::status_code(
     httr::HEAD("https://www.clinicaltrials.gov/",
                httr::timeout(10L))) != 200L
-  ) return(exit_file("Reason: CTGOV not working"))
+  ) return(exit_file("Reason: CTGOV2 not working"))
 
   # do tests
-  source("ctrdata_ctgov_2023api.R", local = TRUE)
+  source("ctrdata_ctgov2.R", local = TRUE)
 
 }
 tf()
